OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Opgaver",
    "Personal" : "Personligt",
    "{actor} created calendar {calendar}" : "{actor} oprettede kalenderen {calendar}",
    "You created calendar {calendar}" : "Du oprettede kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} sletede kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettede kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} opdaterede kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du opdaterede kalenderen {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} gendannede kalender {calendar}",
    "You restored calendar {calendar}" : "Du gendannede kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du har delt kalenderen {calendar} som offentligt link",
    "You removed public link for calendar {calendar}" : "Du har fjernet det offentlige link til kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} fjernede delingen af  {calendar} fra dig",
    "You unshared calendar {calendar} from {user}" : "Du fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} fjernede delingen af {calendar} fra sig selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalenderen {calendar} med gruppen {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppen {group}",
    "You unshared calendar {calendar} from group {group}" : "Du fjernede delingen af  {calendar} fra gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} fjernede deling af kalenderen {calendar} fra gruppen {group}",
    "Untitled event" : "Unavngiven begivenhed",
    "{actor} created event {event} in calendar {calendar}" : "{actor} oprettede begivenheden {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du oprettede begivenheden {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettede begivenheden {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettede begivenheden {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} opdaterede begivenheden {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du opdaterede begivenheden {event} i kalenderen {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} flyttede begivenhed {event} fra kalender {sourceCalendar} til kalender {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Du flyttede begivenhed {event} fra kalender {sourceCalendar} til kalender {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} gendannede begivenhed {event} i kalender {calendar}",
    "You restored event {event} of calendar {calendar}" : "Du gendannede begivenhed {begivenhed} i kalender {kalender}",
    "Busy" : "Optaget",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} oprettede en opgave {todo} i listen {calendar}",
    "You created to-do {todo} in list {calendar}" : "Du oprettede opgaven {todo} i listen {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} slettede opgaven {todo} fra listen {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Du slettede opgaven {todo} fra listen {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} opdaterede opgaven {todo} i listen {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Du opdaterede opgaven {todo} i listen {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} løste opgaven {todo} i listen {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Du løste opgaven {todo} i listen {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} genåbnede opgaven {todo} i listen {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Du genåbnede opgaven {todo} i listen {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} flyttede opgave {event} fra liste {sourceCalendar} til liste {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du flyttede opgave {event} fra liste {sourceCalendar} til liste {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalender, kontakter og opgaver",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> er blevet ændret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>begivenhed</strong> er blevet ændret",
    "A calendar <strong>to-do</strong> was modified" : "En kalender  <strong>opgave</strong> blev ændret",
    "Contact birthdays" : "Kontakt fødselsdag",
    "Death of %s" : "Død af%s",
    "Untitled calendar" : "Unanvngiven kalender",
    "Calendar:" : "Kalender:",
    "Date:" : "Dato:",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n måned","%n måneder"],
    "_%n day_::_%n days_" : ["%n dag","%n dage"],
    "_%n hour_::_%n hours_" : ["%n time","%n timer"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minutter"],
    "%s (in %s)" : "%s (i %s)",
    "%s (%s ago)" : "%s (%s siden)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Dato: %s",
    "Description: %s" : "Beskrivelse: %s",
    "Where: %s" : "Hvor: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Annulléret: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" er blevet annulleret",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s har accepteret din invitation",
    "%1$s has tentatively accepted your invitation" : "%1$s har foreløbigt accepteret din invitation",
    "%1$s has declined your invitation" : "%1$s har afvist din invitation",
    "%1$s has responded to your invitation" : "%1$s har svaret på din invitation",
    "Invitation updated: %1$s" : "Invitation opdateret: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s opdaterede begivenheden \"%2$s\"",
    "Invitation: %1$s" : "Invitation: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s vil gerne invitere dig til \"%2$s\"",
    "Organizer:" : "Arrangør:",
    "Attendees:" : "Deltagere:",
    "Title:" : "Titel:",
    "Time:" : "Tid:",
    "Location:" : "Sted:",
    "Link:" : "Link:",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "More options …" : "Flere indstillinger…",
    "More options at %s" : "Flere muligheder på %s",
    "Contacts" : "Kontakter",
    "{actor} created address book {addressbook}" : "{actor} oprettede adressebog {addressbook}",
    "You created address book {addressbook}" : "Du oprettede adressebog {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} slattede adressebog {addressbook}",
    "You deleted address book {addressbook}" : "Du slettede adressebog {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} opdaterede adressebog {addressbook}",
    "You updated address book {addressbook}" : "Du opdaterede adressebog {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} delte adressebog {addressbook} med dig",
    "You shared address book {addressbook} with {user}" : "Du delte adressebog {addressbook} med {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} delte adressebog {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} fjernede delingen af adressebog {addressbook} med dig",
    "You unshared address book {addressbook} from {user}" : "Du fjernede delingen af adressebog {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} fjernede delingen af adressebog {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} fjernede delingen af adressebog {addressbook} med sig selv",
    "You shared address book {addressbook} with group {group}" : "Du delte adressebog {addressbook} med gruppen {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} delte adressebog {addressbook} med gruppen {group}",
    "You unshared address book {addressbook} from group {group}" : "Du fjernede delingen af adressebog {addressbook} fra gruppen {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} fjernede delingen af adressebog {addressbook} med gruppen {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} oprettede kontakten {card} i adressebog {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Du oprettede kontakten {card} i adressebog {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} slettede kontakten {card} i adressebog {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Du slettede kontakten {card} i adressebog {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} opdaterede kontakten {card} i adressebog {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Du opdaterede kontakten {card} i adressebog {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "En <strong>kontakt</strong> eller <strong>adressebog</strong> blev ændret",
    "Accounts" : "Konti",
    "System address book which holds all accounts" : "Systemets adressebog, som indeholder alle konti",
    "File is not updatable: %1$s" : "Filen kan ikke updateres: %1$s",
    "Could not write to final file, canceled by hook" : "Kunne ikke skrive til den endelige fil, annulleret af hook",
    "Could not write file contents" : "Kunne ikke skrive filindhold",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Fejl under kopiering af fil til placering (kopieret: %1$s, forventet filstørrelse: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Forventede filstørrelse på %1$s, men læste (fra Nextcloud-klienten) og skrev (til Nextcloud-lageret) %2$s. Det kan enten være et netværksproblem på afsendersiden eller et problem med at skrive til lageret på serversiden.",
    "Could not rename part file to final file, canceled by hook" : "Kunne ikke omdøbe delfilen til den endelige fil, annulleret af hook",
    "Could not rename part file to final file" : "Delfilen kunne ikke omdøbes til den endelige fil",
    "Failed to check file size: %1$s" : "Kunne ikke kontrollere filstørrelsen: %1$s",
    "Could not open file" : "Kunne ikke åbne fil",
    "Encryption not ready: %1$s" : "Kryptering ikke klar: %1$s",
    "Failed to open file: %1$s" : "Kunne ikke åbne fil: %1$s",
    "Failed to unlink: %1$s" : "Tilknytningen kunne ikke fjernes: %1$s",
    "Invalid chunk name" : "Ugyldigt stykke navn",
    "Could not rename part file assembled from chunks" : "Kunne ikke omdøbe delfilen samlet fra stykker",
    "Failed to write file contents: %1$s" : "Kunne ikke skrive filindhold: %1$s",
    "File not found: %1$s" : "Fil ikke fundet: %1$s",
    "System is in maintenance mode." : "Systemet er i vedligeholdelsestilstand.",
    "Upgrade needed" : "Opgradering er nødvendig",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s skal konfigureres til at bruge HTTPS for at kunne bruge CalDAV og CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerer en CalDAV-konto",
    "Configures a CardDAV account" : "Konfigurerer en CardDAV-konto",
    "Events" : "Begivenheder",
    "Untitled task" : "Unavngivet opgave",
    "Completed on %s" : "Fuldført den %s",
    "Due on %s by %s" : "Forfalder på %s til %s",
    "Due on %s" : "Forfalder på %s",
    "DAV system address book" : "DAV system adressebog",
    "No outstanding DAV system address book sync." : "Ingen udestående synkronisering af DAV-systemets adressebog.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemets adressebogssynkronisering er ikke kørt endnu, da din instans har mere end 1000 brugere, eller fordi der opstod en fejl. Kør det manuelt ved at kalde \"occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Kunne ikke kontrollere, at din webserver er korrekt konfigureret til at tillade filsynkronisering over WebDAV. Tjek venligst manuelt.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Din webserver er endnu ikke sat korrekt op til at tillade filsynkronisering, fordi WebDAV-grænsefladen ser ud til at være i stykker.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Din webserver er korrekt konfigureret til at tillade filsynkronisering over WebDAV.",
    "Migrated calendar (%1$s)" : "Migreret kalender (%1$s)",
    "Calendars including events, details and attendees" : "Kalendere indeholdende begivenheder, detaljer og deltagere",
    "Contacts and groups" : "Kontakter og grupper",
    "WebDAV" : "WebDAV",
    "First day" : "Første dag",
    "Last day (inclusive)" : "Sidste dag (indklusiv)",
    "Short absence status" : "Kort fraværsstatus",
    "Long absence Message" : "Langt fravær besked",
    "Save" : "Gem",
    "Disable absence" : "Deaktiver fravær",
    "Absence saved" : "Fraværet er gemt",
    "Failed to save your absence settings" : "Kunne ikke gemme dine fraværsindstillinger",
    "Absence cleared" : "Fravær fjernet",
    "Failed to clear your absence settings" : "Kunne ikke rydde dine fraværsindstillinger",
    "Time zone:" : "Tidszone:",
    "to" : "til",
    "Delete slot" : "Slet slot",
    "No working hours set" : "Arbejdstider er ikke sat",
    "Add slot" : "Tilføj slot",
    "Weekdays" : "Hverdage",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Pick a start time for {dayName}" : "Vælg et starttidspunkt for {dayName}",
    "Pick a end time for {dayName}" : "Vælg et sluttidspunkt for {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Indstil automatisk brugerstatus til \"Forstyr ikke\" uden for tilgængelighed for at slå alle notifikationer fra.",
    "Failed to load availability" : "Kunne ikke indlæse tilgængelighed",
    "Saved availability" : "Gemt tilgængelighed",
    "Failed to save availability" : "Kunne ikke gemme tilgængelighed",
    "Availability" : "tilgængelighed",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Hvis du konfigurerer dine arbejdstider, vil andre se, når du er fraværende, når de booker et møde.",
    "Absence" : "Fravær",
    "Configure your next absence period." : "Konfigurer din næste fraværsperiode.",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Send invitation til deltagere",
    "Automatically generate a birthday calendar" : "Generer en fødselsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalendere vil blive oprettet af et job, der kører i baggrunden.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derfor vil de ikke blive synlige med det samme efter aktivering, men vil vise sig efter noget tid.",
    "Send notifications for events" : "Send meddelelser om begivenheder",
    "Notifications are sent via background jobs, so these must occur often enough." : "Underretninger sendes via baggrundsjob, så disse skal ske ofte nok.",
    "Send reminder notifications to calendar sharees as well" : "Send også påmindelsesmeddelelser til kalenderdelinger",
    "Reminders are always sent to organizers and attendees." : "Påmindelser sendes altid til arrangører og deltagere.",
    "Enable notifications for events via push" : "Aktiver notifikationer for begivenheder via push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer også {calendarappstoreopen}Kalender-appen{linkclose}, eller {calendardocopen}tilslut dit skrivebord og din mobil til synkronisering ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Sørg for at konfigurere {emailopen}e-mail-serveren{linkclose} korrekt.",
    "There was an error updating your attendance status." : "Der opstod en fejl under opdatering af din fremmødestatus.",
    "Please contact the organizer directly." : "Kontakt venligst arrangøren direkte.",
    "Are you accepting the invitation?" : "Accepter du invitationen?",
    "Tentative" : "Foreløbig",
    "Your attendance was updated successfully." : "Dit tilstedeværelse blev opdateret.",
    "To-dos" : "Opgaver",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Hvis du konfigurerer din arbejdstid, vil andre brugere se, når du er fraværende, når de booker et møde."
},
"nplurals=2; plural=(n != 1);");
